@@ -7,7 +7,7 @@ import io
 import h5py
 
 bio = io.BytesIO()
-with h5py.File(bio) as f:
+with h5py.File(bio, 'w') as f:
     f['dataset'] = range(10)
 
 data = bio.getvalue() # data is a regular Python bytes object.
